ExecutorConfig

Struct ExecutorConfig 

pub struct ExecutorConfig {
    pub sync_queue_size: usize,
    pub local_queue_size: usize,
    pub max_interval: u32,
    pub waker: Option<Waker>,
}
Configuration for Executor.

Fields

sync_queue_size: usize

The size of the sync queue, which holds task id’s for cross-thread wakes.

This is fixed and will create backpressure when full.

local_queue_size: usize

The size of the local queues, which hold tasks for same-thread execution.

This is dynamically resized to avoid blocking.

max_interval: u32

The maximum number of hot tasks to run in each tick.

waker: Option<Waker>

A waker to be waken when a task is scheduled from other thread.

This is useful for waking up drivers that switch to kernel state when idle.

Enable notify-always feature to wake this waker on every schedule, even if the executor is already awake.